from datetime import datetime

from django.utils import timezone


def local_datetime(year, month, day):
    """
    Returns a timezone aware version of a date, using the current timezone.
    """

    date = datetime(year, month, day)
    return timezone.make_aware(date, timezone.get_current_timezone())


def local_datetime_today():
    """
    Returns today at midnight as a timezone aware datetime object, using the
    current timezone.
    """

    today = timezone.now()
    return local_datetime(today.year, today.month, today.day)



from django.contrib.sites.models import Site, RequestSite


def current_site(request):
    """
    A template context processor that adds the current Django Site object to the 
    template context. Uses RequestSite as fallback.
    """

    context = {}

    try:
        context['site'] = Site.objects.get_current()

    except Site.DoesNotExist:
        context['site'] = RequestSite(request)

    return context



import logging

from django.conf import settings
from django.contrib.sites.models import Site
from django.core.mail import EmailMultiAlternatives
from django.template.loader import render_to_string
from django.utils.encoding import force_unicode

logger = logging.getLogger(__name__)


def send_html_email(recipients, template_prefix, context={}, from_address=None, headers={}):
    """
    Sends an email with text and HTML content. Adds current site, media and 
    static URLs to template context.

    If ``template_prefix`` is 'account/password_reset', the following templates
    are used:
        * account/password_reset.txt (plain text version)
        * account/password_reset.html (HTML version)
        * account/password_reset_subject.txt (plain text subject, one line only)
    """

    # Ensure the recipients are a list
    if not type(recipients) == list:
        recipients = [recipients]

    # Set default from address
    if from_address is None:
        from_address = settings.DEFAULT_FROM_EMAIL

    # Add current site to context if not present
    if not 'site' in context:
        context['site'] = Site.objects.get_current()

    # Media and static URLs with or without domain prefix
    if not 'MEDIA_URL' in context:
        if settings.MEDIA_URL.startswith(('http', '//')):
            context['MEDIA_URL'] = settings.MEDIA_URL
        else:
            context['MEDIA_URL'] = 'http://%s%s' % (
                Site.objects.get_current().domain, 
                settings.MEDIA_URL
            )

    if not 'STATIC_URL' in context:
        if settings.STATIC_URL.startswith(('http', '//')):
            context['STATIC_URL'] = settings.STATIC_URL
        else:
            context['STATIC_URL'] = 'http://%s%s' % (
                Site.objects.get_current().domain, 
                settings.STATIC_URL
            )

    # Render templates
    subject = render_to_string(template_prefix + '_subject.txt', context).strip()
    text_content = render_to_string(template_prefix + '.txt', context)
    html_content = render_to_string(template_prefix + '.html', context)

    # Ensure there are no newlines in subject
    subject = ' '.join(subject.splitlines())

    # In case the text used lazy version of ugettext
    subject = force_unicode(subject)

    # Compose the email
    msg = EmailMultiAlternatives(
        subject, 
        text_content, 
        from_address, 
        recipients, 
        headers=headers
    )
    msg.attach_alternative(html_content, 'text/html')

    # Try to send mail, log exceptions
    try:
        msg.send(fail_silently=False)
    except Exception:
        logger.exception('Sending email to %s with subject "%s" failed.' % (
            recipients, 
            subject
        ))
        return False

    return True



from django.http import Http404


def superuser_required(function):
    """
    Limit a view to superusers. Raises a 404 if user is not a superuser, security
    through obscurity.

    Usage in views:
        @superuser_required
        def index(request):
            ...


    Usage in URL config:
        url(r'^$', superuser_required('views.index'), name='index'),
    """

    def _inner(request, *args, **kwargs):
        if not request.user.is_superuser:
            raise Http404('Superusers only.')
        return function(request, *args, **kwargs)
    return _inner


def staff_required(function):
    """
    Limit a view to staff users. Raises a 404 if user is not staff, security
    through obscurity.

    Usage in views:
        @staff_required
        def index(request):
            ...


    Usage in URL config:
        url(r'^$', staff_required('views.index'), name='index'),
    """

    def _inner(request, *args, **kwargs):
        if not request.user.is_staff:
            raise Http404('Staff users only.')
        return function(request, *args, **kwargs)
    return _inner



"""
S3 storages with predefined locations, to separate static files and user uploads.
"""
from storages.backends.s3boto import S3BotoStorage

# Static location with predefined location
S3BotoStorageStatic = lambda: S3BotoStorage(location='static')

# Media (user uploads) location with predefined location
S3BotoStorageMedia  = lambda: S3BotoStorage(location='media')



from django.db import models
from django.utils.translation import ugettext_lazy as _


class TimestampedModel(models.Model):
    """
    Abstract class that automatically timestamps object instances upon 
    creation and modification.
    """

    creation_time = models.DateTimeField(_('creation time'), auto_now_add=True)
    modification_time = models.DateTimeField(_('modification time'), auto_now=True)

    class Meta:
        abstract = True



#!/usr/bin/env python
import os
import sys

from groove import __version__
from setuptools import setup, find_packages

# Publish to Pypi
if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

setup(
    name='django-groove',
    version=__version__,
    description='Various utilities for Django projects.',
    long_description=open('README.md').read(),
    author='Funkbit',
    author_email='post@funkbit.no',
    url='https://github.com/funkbit/django-groove',
    include_package_data=True,
    packages=find_packages(),
    tests_require=['django>=1.4,<1.5'],
    license='BSD',
    classifiers=(
        "Development Status :: 3 - Alpha",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
    )
)



from django.conf import settings
from django.utils import translation
from haystack.indexes import SearchField


class L10NCharField(SearchField):
    """
    Translatable CharField for django-haystack.

    Since the building of search indexes is triggered by management commands,
    and they are in the en_US locale by default, we need to explicitly activate
    the current translation to have translated URLs in the search results.

    More information:
    https://github.com/toastdriven/django-haystack/issues/609
    """

    def prepare_template(self, obj):
        translation.activate(settings.LANGUAGE_CODE)
        return super(L10NCharField, self).prepare_template(obj)
